shared

package
v0.0.0-...-1baf13c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 11, 2019 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetDSN

func GetDSN(driver, addr, dbname string) string

GetDSN builds a DSN url to connect to the database.

func Migrate

func Migrate(driver string)

Migrate runs a migration based on the chosen driver, and the env variables below.

  • PGUSER
  • CRUSER
  • PGPASSWORD
  • CRPASSWORD
  • PGPORT
  • CRPORT
  • DBNAME

All the env variables are optional, the correct values will be chosen automatically.

Types

This section is empty.

Source Files

  • migrate.go

Jump to